@@ -15,25 +15,13 @@
 # https://github.com/DiffSK/configobj
 
 import sys
-# StringIO is used to simulate config files during doctests
-if sys.version_info >= (3,):
-    # Python 3.x case (io does exist in 2.7, but better to use the 2.x case):
-    #http://bugs.python.org/issue8025
-    from io import StringIO
-else:
-    # Python 2.x case, explicitly NOT using cStringIO due to unicode edge cases
-    from StringIO import StringIO
 
-import os
+from io import StringIO
+
 import sys
-INTP_VER = sys.version_info[:2]
-if INTP_VER < (2, 2):
-    raise RuntimeError("Python v.2.2 or later needed")
-
-from codecs import BOM_UTF8
 
 from configobj import *
-from configobj.validate import Validator, VdtValueTooSmallError
+from configobj.validate import Validator
 
 
 def _test_validate():
@@ -969,7 +957,7 @@ if __name__ == '__main__':
     a = ConfigObj(testconfig1.split('\n'), raise_errors=True)
     b = ConfigObj(testconfig2.split(b'\n'), raise_errors=True)
     i = ConfigObj(testconfig6.split(b'\n'), raise_errors=True)
-    globs.update({'INTP_VER': INTP_VER, 'a': a, 'b': b, 'i': i})
+    globs.update({'a': a, 'b': b, 'i': i})
     pre_failures, pre_tests = doctest.testmod(
         m, globs=globs,
         optionflags=doctest.IGNORE_EXCEPTION_DETAIL | doctest.ELLIPSIS)
